"""Intuitive Git for Python."""
from ._subprocess import Git
from ._version import __version__

__all__ = ["__version__", "Git"]
